from setuptools import setup

setup(
    name='privacy.qa.win',
    description='Testing library',
    author='Teal team',
    version='0.0.1',
    packages=['privacy.qa.win'],
    classifiers=['Programming Language :: Python :: 3'],
)
